@@ -30,7 +30,8 @@ class AbstractTransaction(AbstractEntry):
         asset: str,
         transaction_type: str,
         spot_price: RP2Decimal,
-        unique_id: Optional[int] = None,
+        internal_id: Optional[int] = None,
+        unique_id: Optional[str] = None,
         notes: Optional[str] = None,
     ) -> None:
         super().__init__(configuration, asset)
@@ -38,7 +39,8 @@ class AbstractTransaction(AbstractEntry):
         self.__timestamp: datetime = configuration.type_check_timestamp_from_string("timestamp", timestamp)
         self.__transaction_type: TransactionType = TransactionType.type_check_from_string("transaction_type", transaction_type)
         self.__spot_price: RP2Decimal = configuration.type_check_positive_decimal("spot_price", spot_price)
-        self.__unique_id: int = configuration.type_check_unique_id("unique_id", unique_id) if unique_id is not None else id(self)
+        self.__internal_id: int = configuration.type_check_internal_id("internal_id", internal_id) if internal_id is not None else id(self)
+        self.__unique_id: str = configuration.type_check_string("unique_id", unique_id) if unique_id is not None else ""
         self.__notes = configuration.type_check_string("notes", notes) if notes else ""
 
     @classmethod
@@ -53,18 +55,18 @@ class AbstractTransaction(AbstractEntry):
             return False
         if not isinstance(other, AbstractTransaction):
             raise RP2TypeError(f"Operand has non-AbstractTransaction value {repr(other)}")
-        # By definition, unique_id can uniquely identify a transaction: this works even if it's the ODS line from the spreadsheet,
+        # By definition, internal_id can uniquely identify a transaction: this works even if it's the ODS line from the spreadsheet,
         # since there are no cross-asset transactions (so a spreadsheet line points to a unique transaction for that asset).
-        result: bool = self.unique_id == other.unique_id
+        result: bool = self.internal_id == other.internal_id
         return result
 
     def __ne__(self, other: object) -> bool:
         return not self.__eq__(other)
 
     def __hash__(self) -> int:
-        # By definition, unique_id can uniquely identify a transaction: this works even if it's the ODS line from the spreadsheet,
+        # By definition, internal_id can uniquely identify a transaction: this works even if it's the ODS line from the spreadsheet,
         # since there are no cross-asset transactions (so a spreadsheet line points to a unique transaction for that asset).
-        return hash(self.unique_id)
+        return hash(self.internal_id)
 
     def to_string(self, indent: int = 0, repr_format: bool = True, extra_data: Optional[List[str]] = None) -> str:
         class_specific_data: List[str] = []
@@ -81,8 +83,8 @@ class AbstractTransaction(AbstractEntry):
         return super().to_string(indent=indent, repr_format=repr_format, extra_data=class_specific_data)
 
     @property
-    def unique_id(self) -> str:
-        return str(self.__unique_id)
+    def internal_id(self) -> str:
+        return str(self.__internal_id)
 
     @property
     def timestamp(self) -> datetime:
@@ -96,6 +98,10 @@ class AbstractTransaction(AbstractEntry):
     def spot_price(self) -> RP2Decimal:
         return self.__spot_price
 
+    @property
+    def unique_id(self) -> str:
+        return str(self.__unique_id)
+
     @property
     def notes(self) -> str:
         return self.__notes
