@@ -18,6 +18,7 @@ from pathlib import Path
 from typing import Any, Dict, List, Optional
 
 import ezodf
+
 from rp2.abstract_transaction import AbstractTransaction
 from rp2.configuration import MAX_DATE, MIN_DATE, Configuration
 from rp2.entry_types import EntrySetType
@@ -27,7 +28,7 @@ from rp2.intra_transaction import IntraTransaction
 from rp2.logger import LOGGER
 from rp2.out_transaction import OutTransaction
 from rp2.rp2_decimal import RP2Decimal
-from rp2.rp2_error import RP2ValueError
+from rp2.rp2_error import RP2Error, RP2ValueError
 from rp2.transaction_set import TransactionSet
 
 _TABLE_END: str = "TABLE END"
@@ -155,23 +156,26 @@ def _get_decimal_constructor_argument_names(class_name: str) -> List[str]:
     return result
 
 
-# Add configuration and unique_id to argument pack and turn floats to strings to maximize decimal precision. See comment inside the function.
+# Add configuration and internal_id to argument pack and turn floats to strings to maximize decimal precision. See comment inside the function.
 def _process_constructor_argument_pack(
     configuration: Configuration,
     argument_pack: Dict[str, Any],
-    unique_id: int,
+    internal_id: int,
     class_name: str,
 ) -> Dict[str, Any]:
-    argument_pack.update({"configuration": configuration, "unique_id": unique_id})
+    argument_pack.update({"configuration": configuration, "internal_id": internal_id})
     numeric_parameters: List[str] = _get_decimal_constructor_argument_names(class_name)
     for numeric_parameter in numeric_parameters:
         if numeric_parameter in argument_pack:
-            value: Optional[float] = argument_pack[numeric_parameter]
-            # It would be ideal to pass a string directly to the RP2Decimal constructor for maximum precision, but due to ezodf limitations we
-            # cannot get the string representation directly from the spreadsheet (see the comment on cell format inside parse_ods() for more
-            # detail), so at parse time we have to get the float value from the cell. Here we convert the float to string, which allows us to
-            # initialize a maximum-precision RP2Decimal (11 decimal digits is enough precision for millisats).
-            argument_pack[numeric_parameter] = RP2Decimal(f"{value:.11f}") if value is not None else None
+            try:
+                value: Optional[float] = argument_pack[numeric_parameter]
+                # It would be ideal to pass a string directly to the RP2Decimal constructor for maximum precision, but due to ezodf limitations we
+                # cannot get the string representation directly from the spreadsheet (see the comment on cell format inside parse_ods() for more
+                # detail), so at parse time we have to get the float value from the cell. Here we convert the float to string, which allows us to
+                # initialize a maximum-precision RP2Decimal (11 decimal digits is enough precision for millisats).
+                argument_pack[numeric_parameter] = RP2Decimal(f"{value:.11f}") if value is not None else None
+            except (ValueError, RP2Error) as exc:
+                raise RP2ValueError(f"Argument '{numeric_parameter}' has non-numeric value: {value}") from exc
 
     return argument_pack
 
@@ -179,23 +183,23 @@ def _process_constructor_argument_pack(
 def _create_transaction(
     configuration: Configuration,
     entry_set_type: EntrySetType,
-    unique_id: int,
+    internal_id: int,
     row_values: List[Any],
 ) -> AbstractTransaction:
     transaction: AbstractTransaction
     EntrySetType.type_check("entry_set_type", entry_set_type)
-    configuration.type_check_unique_id("unique_id", unique_id)
+    configuration.type_check_internal_id("internal_id", internal_id)
     if entry_set_type == EntrySetType.IN:
         argument_pack: Dict[str, Any] = configuration.get_in_table_constructor_argument_pack(row_values)
-        argument_pack = _process_constructor_argument_pack(configuration, argument_pack, unique_id, "InTransaction")
+        argument_pack = _process_constructor_argument_pack(configuration, argument_pack, internal_id, "InTransaction")
         transaction = InTransaction(**argument_pack)
     elif entry_set_type == EntrySetType.OUT:
         argument_pack = configuration.get_out_table_constructor_argument_pack(row_values)
-        argument_pack = _process_constructor_argument_pack(configuration, argument_pack, unique_id, "OutTransaction")
+        argument_pack = _process_constructor_argument_pack(configuration, argument_pack, internal_id, "OutTransaction")
         transaction = OutTransaction(**argument_pack)
     elif entry_set_type == EntrySetType.INTRA:
         argument_pack = configuration.get_intra_table_constructor_argument_pack(row_values)
-        argument_pack = _process_constructor_argument_pack(configuration, argument_pack, unique_id, "IntraTransaction")
+        argument_pack = _process_constructor_argument_pack(configuration, argument_pack, internal_id, "IntraTransaction")
         transaction = IntraTransaction(**argument_pack)
     return transaction
 
