@@ -12,6 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import logging
 from datetime import date
 from enum import Enum
 from pathlib import Path
@@ -22,10 +23,12 @@ from rp2.computed_data import ComputedData
 from rp2.entry_types import TransactionType
 from rp2.gain_loss import GainLoss
 from rp2.gain_loss_set import GainLossSet
-from rp2.logger import LOGGER
+from rp2.logger import create_logger
 from rp2.plugin.report.abstract_ods_generator import AbstractODSGenerator
 from rp2.rp2_error import RP2TypeError
 
+LOGGER: logging.Logger = create_logger("tax_report_us")
+
 
 class SheetNames(Enum):
     AIRDROPS: str = "Airdrops"
@@ -33,6 +36,7 @@ class SheetNames(Enum):
     DONATIONS: str = "Donations"
     GIFTS: str = "Gifts"
     HARDFORKS: str = "Hard Forks"
+    INCOME: str = "Income"
     INTEREST: str = "Interest"
     INVESTMENT_EXPENSES: str = "Investment Expenses"
     MINING: str = "Mining"
@@ -48,6 +52,7 @@ _SHEET_TO_TYPE: Dict[str, TransactionType] = {
     SheetNames.DONATIONS.value: TransactionType.DONATE,
     SheetNames.GIFTS.value: TransactionType.GIFT,
     SheetNames.HARDFORKS.value: TransactionType.HARDFORK,
+    SheetNames.INCOME.value: TransactionType.INCOME,
     SheetNames.INTEREST.value: TransactionType.INTEREST,
     SheetNames.INVESTMENT_EXPENSES.value: TransactionType.MOVE,
     SheetNames.MINING.value: TransactionType.MINING,
@@ -157,9 +162,10 @@ class Generator(AbstractODSGenerator):
             self._fill_cell(sheet, row_index, 7, "", visual_style=transparent_vs)
             self._fill_cell(sheet, row_index, 8, gain_loss.fiat_gain, visual_style=transparent_vs, data_style="fiat")
             self._fill_cell(sheet, row_index, 9, transaction_type, visual_style=taxable_event_note_vs)
-            self._fill_cell(sheet, row_index, 11, taxable_event_note, visual_style=taxable_event_note_vs)
-            self._fill_cell(sheet, row_index, 12, "LONG" if gain_loss.is_long_term_capital_gains() else "SHORT", visual_style=taxable_event_note_vs)
-            self._fill_cell(sheet, row_index, 13, gain_loss.taxable_event.timestamp, visual_style=taxable_event_note_vs)
+            self._fill_cell(sheet, row_index, 12, taxable_event_note, visual_style=taxable_event_note_vs)
+            self._fill_cell(sheet, row_index, 13, gain_loss.taxable_event.unique_id, visual_style=taxable_event_note_vs)
+            self._fill_cell(sheet, row_index, 14, "LONG" if gain_loss.is_long_term_capital_gains() else "SHORT", visual_style=taxable_event_note_vs)
+            self._fill_cell(sheet, row_index, 15, gain_loss.taxable_event.timestamp, visual_style=taxable_event_note_vs)
 
             if gain_loss.acquired_lot:
                 current_acquired_lot_fraction: int = gain_loss_set.get_acquired_lot_fraction(gain_loss) + 1
@@ -174,10 +180,12 @@ class Generator(AbstractODSGenerator):
                 self._fill_cell(sheet, row_index, 2, gain_loss.acquired_lot.timestamp.strftime("%m/%d/%Y"), visual_style=acquired_lot_note_vs)
                 self._fill_cell(sheet, row_index, 5, gain_loss.fiat_cost_basis, visual_style=acquired_lot_note_vs, data_style="fiat")
                 self._fill_cell(sheet, row_index, 10, acquired_lot_note, visual_style=acquired_lot_note_vs)
+                self._fill_cell(sheet, row_index, 11, gain_loss.acquired_lot.unique_id, visual_style=acquired_lot_note_vs)
             else:
                 self._fill_cell(sheet, row_index, 2, "", visual_style=transparent_vs)
                 self._fill_cell(sheet, row_index, 5, "", visual_style=transparent_vs)
                 self._fill_cell(sheet, row_index, 10, "", visual_style=transparent_vs)
+                self._fill_cell(sheet, row_index, 11, "", visual_style=transparent_vs)
 
             border_suffix = ""
             row_indexes[sheet.name] = row_index + 1
