@@ -16,6 +16,7 @@ import re
 import unittest
 
 from dateutil.tz import tzutc
+
 from rp2.configuration import Configuration
 from rp2.entry_types import TransactionType
 from rp2.in_transaction import InTransaction
@@ -70,13 +71,13 @@ class TestInTransaction(unittest.TestCase):
             RP2Decimal("0"),
             fiat_in_no_fee=RP2Decimal("2000.2"),
             fiat_in_with_fee=RP2Decimal("2000.2"),
-            unique_id=19,
+            internal_id=19,
         )
 
         InTransaction.type_check("my_instance", in_transaction)
         self.assertTrue(in_transaction.is_taxable())
         self.assertEqual(RP2Decimal("2000.2"), in_transaction.fiat_taxable_amount)
-        self.assertEqual("19", in_transaction.unique_id)
+        self.assertEqual("19", in_transaction.internal_id)
         self.assertEqual(2021, in_transaction.timestamp.year)
         self.assertEqual(1, in_transaction.timestamp.month)
         self.assertEqual(2, in_transaction.timestamp.day)
@@ -111,6 +112,7 @@ class TestInTransaction(unittest.TestCase):
   fiat_fee=0.0000
   fiat_in_no_fee=2000.2000
   fiat_in_with_fee=2000.2000
+  unique_id=
   is_taxable=True
   fiat_taxable_amount=2000.2000""",
         )
@@ -128,6 +130,7 @@ class TestInTransaction(unittest.TestCase):
       fiat_fee=0.0000
       fiat_in_no_fee=2000.2000
       fiat_in_with_fee=2000.2000
+      unique_id=
       is_taxable=True
       fiat_taxable_amount=2000.2000
       foobar
@@ -148,6 +151,7 @@ class TestInTransaction(unittest.TestCase):
                 "fiat_fee=0.0000, "
                 "fiat_in_no_fee=2000.2000, "
                 "fiat_in_with_fee=2000.2000, "
+                "unique_id=, "
                 "is_taxable=True, "
                 "fiat_taxable_amount=2000.2000, "
                 "foobar, "
@@ -166,7 +170,7 @@ class TestInTransaction(unittest.TestCase):
             RP2Decimal("1000"),
             RP2Decimal("2.0002"),
             RP2Decimal("20"),
-            unique_id=19,
+            internal_id=19,
         )
         self.assertFalse(in_transaction.is_taxable())
         self.assertEqual(RP2Decimal("0"), in_transaction.fiat_taxable_amount)
@@ -189,6 +193,7 @@ class TestInTransaction(unittest.TestCase):
   fiat_fee=20.0000
   fiat_in_no_fee=2000.2000
   fiat_in_with_fee=2020.2000
+  unique_id=
   is_taxable=False
   fiat_taxable_amount=0.0000""",
         )
@@ -206,7 +211,7 @@ class TestInTransaction(unittest.TestCase):
             RP2Decimal("0"),
             fiat_in_no_fee=RP2Decimal("2000.2"),
             fiat_in_with_fee=RP2Decimal("2000.2"),
-            unique_id=19,
+            internal_id=19,
         )
         in_transaction2: InTransaction = InTransaction(
             self._configuration,
@@ -220,7 +225,7 @@ class TestInTransaction(unittest.TestCase):
             RP2Decimal("0"),
             fiat_in_no_fee=RP2Decimal("2000.2"),
             fiat_in_with_fee=RP2Decimal("2000.2"),
-            unique_id=19,
+            internal_id=19,
         )
         in_transaction3: InTransaction = InTransaction(
             self._configuration,
@@ -234,7 +239,7 @@ class TestInTransaction(unittest.TestCase):
             RP2Decimal("0"),
             fiat_in_no_fee=RP2Decimal("2000.2"),
             fiat_in_with_fee=RP2Decimal("2000.2"),
-            unique_id=20,
+            internal_id=20,
         )
         self.assertEqual(in_transaction, in_transaction)
         self.assertEqual(in_transaction, in_transaction2)
@@ -257,7 +262,7 @@ class TestInTransaction(unittest.TestCase):
             RP2Decimal("0"),
             fiat_in_no_fee=RP2Decimal("2000.2"),
             fiat_in_with_fee=RP2Decimal("2000.2"),
-            unique_id=19,
+            internal_id=19,
         )
         with self.assertRaisesRegex(RP2TypeError, "Parameter 'indent' has non-integer value"):
             in_transaction.to_string(None, repr_format=False, extra_data=["foobar", "qwerty"])  # type: ignore
@@ -286,7 +291,7 @@ class TestInTransaction(unittest.TestCase):
                     RP2Decimal("10000"),
                     RP2Decimal("1"),
                     RP2Decimal("0"),
-                    unique_id=45,
+                    internal_id=45,
                 ),
             )
         with self.assertRaisesRegex(RP2TypeError, "Parameter 'configuration' is not of type Configuration: .*"):
@@ -303,7 +308,7 @@ class TestInTransaction(unittest.TestCase):
                 RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
-                unique_id=19,
+                internal_id=19,
             )
         with self.assertRaisesRegex(RP2TypeError, "Parameter 'configuration' is not of type Configuration: .*"):
             # Bad configuration
@@ -319,10 +324,10 @@ class TestInTransaction(unittest.TestCase):
                 RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
-                unique_id=19,
+                internal_id=19,
             )
-        with self.assertRaisesRegex(RP2ValueError, "Parameter 'unique_id' has non-positive value .*"):
-            # Bad unique_id
+        with self.assertRaisesRegex(RP2ValueError, "Parameter 'internal_id' has non-positive value .*"):
+            # Bad internal_id
             InTransaction(
                 self._configuration,
                 "2021-01-02T08:42:43.882Z",
@@ -335,10 +340,10 @@ class TestInTransaction(unittest.TestCase):
                 RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
-                unique_id=-19,
+                internal_id=-19,
             )
-        with self.assertRaisesRegex(RP2TypeError, "Parameter 'unique_id' has non-integer .*"):
-            # Bad unique_id
+        with self.assertRaisesRegex(RP2TypeError, "Parameter 'internal_id' has non-integer .*"):
+            # Bad internal_id
             InTransaction(
                 self._configuration,
                 "2021-01-02T08:42:43.882Z",
@@ -351,7 +356,7 @@ class TestInTransaction(unittest.TestCase):
                 RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
-                unique_id="19",  # type: ignore
+                internal_id="19",  # type: ignore
             )
         with self.assertRaisesRegex(RP2ValueError, "Error parsing parameter 'timestamp': Unknown string format: .*"):
             # Bad timestamp
@@ -367,7 +372,7 @@ class TestInTransaction(unittest.TestCase):
                 RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
-                unique_id=19,
+                internal_id=19,
             )
         with self.assertRaisesRegex(RP2ValueError, "Parameter 'timestamp' value has no timezone info: .*"):
             # Bad timestamp
@@ -383,7 +388,7 @@ class TestInTransaction(unittest.TestCase):
                 RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
-                unique_id=19,
+                internal_id=19,
             )
         with self.assertRaisesRegex(RP2TypeError, "Parameter 'timestamp' has non-string value .*"):
             # Bad timestamp
@@ -399,7 +404,7 @@ class TestInTransaction(unittest.TestCase):
                 RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
-                unique_id=19,
+                internal_id=19,
             )
         with self.assertRaisesRegex(RP2ValueError, "Parameter 'asset' value is not known: .*"):
             # Bad asset
@@ -415,7 +420,7 @@ class TestInTransaction(unittest.TestCase):
                 RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
-                unique_id=19,
+                internal_id=19,
             )
         with self.assertRaisesRegex(RP2TypeError, "Parameter 'asset' has non-string value .*"):
             # Bad asset
@@ -431,7 +436,7 @@ class TestInTransaction(unittest.TestCase):
                 RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
-                unique_id=19,
+                internal_id=19,
             )
         with self.assertRaisesRegex(RP2ValueError, "Parameter 'exchange' value is not known: .*"):
             # Bad exchange
@@ -447,7 +452,7 @@ class TestInTransaction(unittest.TestCase):
                 RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
-                unique_id=19,
+                internal_id=19,
             )
         with self.assertRaisesRegex(RP2TypeError, "Parameter 'exchange' has non-string value .*"):
             # Bad exchange
@@ -463,7 +468,7 @@ class TestInTransaction(unittest.TestCase):
                 RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
-                unique_id=19,
+                internal_id=19,
             )
         with self.assertRaisesRegex(RP2ValueError, "Parameter 'holder' value is not known: .*"):
             # Bad holder
@@ -479,7 +484,7 @@ class TestInTransaction(unittest.TestCase):
                 RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
-                unique_id=19,
+                internal_id=19,
             )
         with self.assertRaisesRegex(RP2TypeError, "Parameter 'holder' has non-string value .*"):
             # Bad holder
@@ -495,7 +500,7 @@ class TestInTransaction(unittest.TestCase):
                 RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
-                unique_id=19,
+                internal_id=19,
             )
         with self.assertRaisesRegex(RP2ValueError, ".*InTransaction .*, id.*invalid transaction type.*"):
             # Bad transaction type
@@ -511,7 +516,7 @@ class TestInTransaction(unittest.TestCase):
                 RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
-                unique_id=19,
+                internal_id=19,
             )
         with self.assertRaisesRegex(RP2ValueError, "Parameter 'transaction_type' has invalid transaction type value: .*"):
             # Bad transaction type
@@ -527,7 +532,7 @@ class TestInTransaction(unittest.TestCase):
                 RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
-                unique_id=19,
+                internal_id=19,
             )
         with self.assertRaisesRegex(RP2ValueError, "Parameter .* has invalid transaction type value: .*"):
             # Bad transaction type
@@ -543,7 +548,7 @@ class TestInTransaction(unittest.TestCase):
                 RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
-                unique_id=19,
+                internal_id=19,
             )
         with self.assertRaisesRegex(RP2TypeError, "Parameter .* has non-string value .*"):
             # Bad transaction type
@@ -559,7 +564,7 @@ class TestInTransaction(unittest.TestCase):
                 RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
-                unique_id=19,
+                internal_id=19,
             )
         with self.assertRaisesRegex(RP2ValueError, ".*InTransaction .*, id.*parameter 'spot_price' cannot be 0"):
             # Bad spot price
@@ -575,7 +580,7 @@ class TestInTransaction(unittest.TestCase):
                 RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
-                unique_id=19,
+                internal_id=19,
             )
         with self.assertRaisesRegex(RP2ValueError, ".*InTransaction .*, id.*parameter 'spot_price' cannot be 0"):
             # Bad spot price
@@ -591,7 +596,7 @@ class TestInTransaction(unittest.TestCase):
                 RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
-                unique_id=19,
+                internal_id=19,
             )
         with self.assertRaisesRegex(RP2ValueError, "Parameter 'spot_price' has non-positive value .*"):
             # Bad spot price
@@ -607,7 +612,7 @@ class TestInTransaction(unittest.TestCase):
                 RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
-                unique_id=19,
+                internal_id=19,
             )
         with self.assertRaisesRegex(RP2TypeError, "Parameter 'spot_price' has non-RP2Decimal value .*"):
             # Bad spot price
@@ -623,7 +628,7 @@ class TestInTransaction(unittest.TestCase):
                 RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
-                unique_id=19,
+                internal_id=19,
             )
         with self.assertRaisesRegex(RP2ValueError, "Parameter 'crypto_in' has zero value"):
             # Bad crypto in
@@ -639,7 +644,7 @@ class TestInTransaction(unittest.TestCase):
                 RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
-                unique_id=19,
+                internal_id=19,
             )
         with self.assertRaisesRegex(RP2ValueError, "Parameter 'crypto_in' has non-positive value .*"):
             # Bad crypto in
@@ -655,7 +660,7 @@ class TestInTransaction(unittest.TestCase):
                 RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
-                unique_id=19,
+                internal_id=19,
             )
         with self.assertRaisesRegex(RP2TypeError, "Parameter 'crypto_in' has non-RP2Decimal value .*"):
             # Bad crypto in
@@ -671,7 +676,7 @@ class TestInTransaction(unittest.TestCase):
                 RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
-                unique_id=19,
+                internal_id=19,
             )
         with self.assertRaisesRegex(RP2ValueError, "Parameter 'fiat_fee' has non-positive value .*"):
             # Bad fiat fee
@@ -687,7 +692,7 @@ class TestInTransaction(unittest.TestCase):
                 RP2Decimal("-20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
-                unique_id=19,
+                internal_id=19,
             )
         with self.assertRaisesRegex(RP2TypeError, "Parameter 'fiat_fee' has non-RP2Decimal value .*"):
             # Bad fiat fee
@@ -703,7 +708,7 @@ class TestInTransaction(unittest.TestCase):
                 "20",  # type: ignore
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
-                unique_id=19,
+                internal_id=19,
             )
         with self.assertRaisesRegex(RP2ValueError, "Parameter 'fiat_in_no_fee' has non-positive value .*"):
             # Bad fiat in no fee
@@ -719,7 +724,7 @@ class TestInTransaction(unittest.TestCase):
                 RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("-2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
-                unique_id=19,
+                internal_id=19,
             )
         with self.assertRaisesRegex(RP2TypeError, "Parameter 'fiat_in_no_fee' has non-RP2Decimal value .*"):
             # Bad fiat in no fee
@@ -735,7 +740,7 @@ class TestInTransaction(unittest.TestCase):
                 RP2Decimal("20"),
                 fiat_in_no_fee="2000.2",  # type: ignore
                 fiat_in_with_fee=RP2Decimal("2020.2"),
-                unique_id=19,
+                internal_id=19,
             )
         with self.assertRaisesRegex(RP2ValueError, "Parameter 'fiat_in_with_fee' has non-positive value .*"):
             # Bad fiat in with fee
@@ -751,7 +756,7 @@ class TestInTransaction(unittest.TestCase):
                 RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("-2020.2"),
-                unique_id=19,
+                internal_id=19,
             )
         with self.assertRaisesRegex(RP2TypeError, "Parameter 'fiat_in_with_fee' has non-RP2Decimal value .*"):
             # Bad fiat in with fee
@@ -767,7 +772,7 @@ class TestInTransaction(unittest.TestCase):
                 RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=(1, 2, 3),  # type: ignore
-                unique_id=19,
+                internal_id=19,
             )
         with self.assertRaisesRegex(RP2TypeError, "Parameter 'notes' has non-string value .*"):
             # Bad notes
@@ -783,7 +788,7 @@ class TestInTransaction(unittest.TestCase):
                 RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
-                unique_id=19,
+                internal_id=19,
                 notes=35.6,  # type: ignore
             )
         with self.assertRaisesRegex(RP2TypeError, "Parameter 'notes' has non-string value .*"):
@@ -800,7 +805,7 @@ class TestInTransaction(unittest.TestCase):
                 RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
-                unique_id=19,
+                internal_id=19,
                 notes=[1, 2, 3],  # type: ignore
             )
 
@@ -818,7 +823,7 @@ class TestInTransaction(unittest.TestCase):
                 RP2Decimal("1000"),
                 fiat_in_no_fee=RP2Decimal("1900.2"),
                 fiat_in_with_fee=RP2Decimal("2000.2"),
-                unique_id=19,
+                internal_id=19,
             )
             self.assertTrue(re.search(".* InTransaction .*, id.*crypto_in.*spot_price != fiat_in_no_fee:.*", log.output[0]))  # type: ignore
 
@@ -836,7 +841,7 @@ class TestInTransaction(unittest.TestCase):
                 RP2Decimal("18"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
-                unique_id=19,
+                internal_id=19,
             )
             self.assertTrue(re.search(".* InTransaction .*, id.*fiat_in_with_fee != fiat_in_no_fee.*fiat_fee:.*", log.output[0]))  # type: ignore
 
