@@ -12,9 +12,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import re
 import unittest
 
 from dateutil.tz import tzutc
+
 from rp2.configuration import Configuration
 from rp2.entry_types import TransactionType
 from rp2.in_transaction import InTransaction
@@ -46,13 +48,13 @@ class TestIntraTransaction(unittest.TestCase):
             RP2Decimal("1000.0"),
             RP2Decimal("2.0002"),
             RP2Decimal("1.9998"),
-            unique_id=19,
+            internal_id=19,
         )
 
         IntraTransaction.type_check("my_instance", intra_transaction)
         self.assertTrue(intra_transaction.is_taxable())
         self.assertEqual(RP2Decimal("0.4"), intra_transaction.fiat_taxable_amount)
-        self.assertEqual("19", intra_transaction.unique_id)
+        self.assertEqual("19", intra_transaction.internal_id)
         self.assertEqual(2021, intra_transaction.timestamp.year)
         self.assertEqual(1, intra_transaction.timestamp.month)
         self.assertEqual(2, intra_transaction.timestamp.day)
@@ -91,6 +93,7 @@ class TestIntraTransaction(unittest.TestCase):
   crypto_received=1.99980000
   crypto_fee=0.00040000
   fiat_fee=0.4000
+  unique_id=
   is_taxable=True
   fiat_taxable_amount=0.4000""",
         )
@@ -110,6 +113,7 @@ class TestIntraTransaction(unittest.TestCase):
       crypto_received=1.99980000
       crypto_fee=0.00040000
       fiat_fee=0.4000
+      unique_id=
       is_taxable=True
       fiat_taxable_amount=0.4000
       foobar
@@ -132,6 +136,7 @@ class TestIntraTransaction(unittest.TestCase):
                 "crypto_received=1.99980000, "
                 "crypto_fee=0.00040000, "
                 "fiat_fee=0.4000, "
+                "unique_id=, "
                 "is_taxable=True, "
                 "fiat_taxable_amount=0.4000, "
                 "foobar, "
@@ -151,7 +156,7 @@ class TestIntraTransaction(unittest.TestCase):
             RP2Decimal("100.0"),
             RP2Decimal("30"),
             RP2Decimal("30"),
-            unique_id=19,
+            internal_id=19,
         )
         self.assertFalse(intra_transaction.is_taxable())
         self.assertEqual(RP2Decimal("0"), intra_transaction.fiat_taxable_amount)
@@ -178,6 +183,7 @@ class TestIntraTransaction(unittest.TestCase):
   crypto_received=30.00000000
   crypto_fee=0.00000000
   fiat_fee=0.0000
+  unique_id=
   is_taxable=False
   fiat_taxable_amount=0.0000""",
         )
@@ -194,7 +200,7 @@ class TestIntraTransaction(unittest.TestCase):
             RP2Decimal("100.0"),
             RP2Decimal("30"),
             RP2Decimal("30"),
-            unique_id=19,
+            internal_id=19,
         )
         intra_transaction2: IntraTransaction = IntraTransaction(
             self._configuration,
@@ -207,7 +213,7 @@ class TestIntraTransaction(unittest.TestCase):
             RP2Decimal("100.0"),
             RP2Decimal("30"),
             RP2Decimal("30"),
-            unique_id=19,
+            internal_id=19,
         )
         intra_transaction3: IntraTransaction = IntraTransaction(
             self._configuration,
@@ -220,7 +226,7 @@ class TestIntraTransaction(unittest.TestCase):
             RP2Decimal("100.0"),
             RP2Decimal("30"),
             RP2Decimal("30"),
-            unique_id=11,
+            internal_id=11,
         )
         self.assertEqual(intra_transaction, intra_transaction)
         self.assertEqual(intra_transaction, intra_transaction2)
@@ -242,7 +248,7 @@ class TestIntraTransaction(unittest.TestCase):
             RP2Decimal("1000.0"),
             RP2Decimal("2.0002"),
             RP2Decimal("1.9998"),
-            unique_id=19,
+            internal_id=19,
         )
         with self.assertRaisesRegex(RP2TypeError, "Parameter 'indent' has non-integer value"):
             intra_transaction.to_string(None, repr_format=False, extra_data=["foobar", "qwerty"])  # type: ignore
@@ -271,7 +277,7 @@ class TestIntraTransaction(unittest.TestCase):
                     RP2Decimal("10000"),
                     RP2Decimal("1"),
                     RP2Decimal("0"),
-                    unique_id=45,
+                    internal_id=45,
                 ),
             )
 
@@ -288,7 +294,7 @@ class TestIntraTransaction(unittest.TestCase):
                 RP2Decimal("1000.0"),
                 RP2Decimal("2.0002"),
                 RP2Decimal("1.9998"),
-                unique_id=19,
+                internal_id=19,
             )
         with self.assertRaisesRegex(RP2TypeError, "Parameter 'configuration' is not of type Configuration: .*"):
             # Bad configuration
@@ -303,10 +309,10 @@ class TestIntraTransaction(unittest.TestCase):
                 RP2Decimal("1000.0"),
                 RP2Decimal("2.0002"),
                 RP2Decimal("1.9998"),
-                unique_id=19,
+                internal_id=19,
             )
-        with self.assertRaisesRegex(RP2ValueError, "Parameter 'unique_id' has non-positive value .*"):
-            # Bad unique_id
+        with self.assertRaisesRegex(RP2ValueError, "Parameter 'internal_id' has non-positive value .*"):
+            # Bad internal_id
             IntraTransaction(
                 self._configuration,
                 "2021-01-02T08:42:43.882Z",
@@ -318,10 +324,10 @@ class TestIntraTransaction(unittest.TestCase):
                 RP2Decimal("1000.0"),
                 RP2Decimal("2.0002"),
                 RP2Decimal("1.9998"),
-                unique_id=-19,
+                internal_id=-19,
             )
-        with self.assertRaisesRegex(RP2TypeError, "Parameter 'unique_id' has non-integer value .*"):
-            # Bad unique_id
+        with self.assertRaisesRegex(RP2TypeError, "Parameter 'internal_id' has non-integer value .*"):
+            # Bad internal_id
             IntraTransaction(
                 self._configuration,
                 "2021-01-02T08:42:43.882Z",
@@ -333,7 +339,7 @@ class TestIntraTransaction(unittest.TestCase):
                 RP2Decimal("1000.0"),
                 RP2Decimal("2.0002"),
                 RP2Decimal("1.9998"),
-                unique_id=(1, 2, 3),  # type: ignore
+                internal_id=(1, 2, 3),  # type: ignore
             )
         with self.assertRaisesRegex(RP2TypeError, "Parameter 'timestamp' has non-string value .*"):
             # Bad timestamp
@@ -348,7 +354,7 @@ class TestIntraTransaction(unittest.TestCase):
                 RP2Decimal("1000.0"),
                 RP2Decimal("2.0002"),
                 RP2Decimal("1.9998"),
-                unique_id=19,
+                internal_id=19,
             )
         with self.assertRaisesRegex(RP2ValueError, "Parameter 'timestamp' value has no timezone info: .*"):
             # Bad timestamp
@@ -363,7 +369,7 @@ class TestIntraTransaction(unittest.TestCase):
                 RP2Decimal("1000.0"),
                 RP2Decimal("2.0002"),
                 RP2Decimal("1.9998"),
-                unique_id=19,
+                internal_id=19,
             )
         with self.assertRaisesRegex(RP2ValueError, "Parameter 'asset' value is not known: .*"):
             # Bad asset
@@ -378,7 +384,7 @@ class TestIntraTransaction(unittest.TestCase):
                 RP2Decimal("1000.0"),
                 RP2Decimal("2.0002"),
                 RP2Decimal("1.9998"),
-                unique_id=19,
+                internal_id=19,
             )
         with self.assertRaisesRegex(RP2TypeError, "Parameter 'asset' has non-string value .*"):
             # Bad asset
@@ -393,7 +399,7 @@ class TestIntraTransaction(unittest.TestCase):
                 RP2Decimal("1000.0"),
                 RP2Decimal("2.0002"),
                 RP2Decimal("1.9998"),
-                unique_id=19,
+                internal_id=19,
             )
         with self.assertRaisesRegex(RP2ValueError, "Parameter 'from_exchange' value is not known: .*"):
             # Bad from exchange
@@ -408,7 +414,7 @@ class TestIntraTransaction(unittest.TestCase):
                 RP2Decimal("1000.0"),
                 RP2Decimal("2.0002"),
                 RP2Decimal("1.9998"),
-                unique_id=19,
+                internal_id=19,
             )
         with self.assertRaisesRegex(RP2TypeError, "Parameter 'from_exchange' has non-string value .*"):
             # Bad from exchange
@@ -423,7 +429,7 @@ class TestIntraTransaction(unittest.TestCase):
                 RP2Decimal("1000.0"),
                 RP2Decimal("2.0002"),
                 RP2Decimal("1.9998"),
-                unique_id=19,
+                internal_id=19,
             )
         with self.assertRaisesRegex(RP2ValueError, "Parameter 'from_holder' value is not known: .*"):
             # Bad from holder
@@ -438,7 +444,7 @@ class TestIntraTransaction(unittest.TestCase):
                 RP2Decimal("1000.0"),
                 RP2Decimal("2.0002"),
                 RP2Decimal("1.9998"),
-                unique_id=19,
+                internal_id=19,
             )
         with self.assertRaisesRegex(RP2TypeError, "Parameter 'from_holder' has non-string value .*"):
             # Bad from holder
@@ -453,7 +459,7 @@ class TestIntraTransaction(unittest.TestCase):
                 RP2Decimal("1000.0"),
                 RP2Decimal("2.0002"),
                 RP2Decimal("1.9998"),
-                unique_id=19,
+                internal_id=19,
             )
         with self.assertRaisesRegex(RP2ValueError, "Parameter 'to_exchange' value is not known: .*"):
             # Bad to exchange
@@ -468,7 +474,7 @@ class TestIntraTransaction(unittest.TestCase):
                 RP2Decimal("1000.0"),
                 RP2Decimal("2.0002"),
                 RP2Decimal("1.9998"),
-                unique_id=19,
+                internal_id=19,
             )
         with self.assertRaisesRegex(RP2TypeError, "Parameter 'to_exchange' has non-string value .*"):
             # Bad to exchange
@@ -483,7 +489,7 @@ class TestIntraTransaction(unittest.TestCase):
                 RP2Decimal("1000.0"),
                 RP2Decimal("2.0002"),
                 RP2Decimal("1.9998"),
-                unique_id=19,
+                internal_id=19,
             )
         with self.assertRaisesRegex(RP2ValueError, "Parameter 'to_holder' value is not known: .*"):
             # Bad to holder
@@ -498,7 +504,7 @@ class TestIntraTransaction(unittest.TestCase):
                 RP2Decimal("1000.0"),
                 RP2Decimal("2.0002"),
                 RP2Decimal("1.9998"),
-                unique_id=19,
+                internal_id=19,
             )
         with self.assertRaisesRegex(RP2TypeError, "Parameter 'to_holder' has non-string value .*"):
             # Bad to holder
@@ -513,7 +519,7 @@ class TestIntraTransaction(unittest.TestCase):
                 RP2Decimal("1000.0"),
                 RP2Decimal("2.0002"),
                 RP2Decimal("1.9998"),
-                unique_id=19,
+                internal_id=19,
             )
         with self.assertRaisesRegex(RP2ValueError, "Parameter 'spot_price' has non-positive value .*"):
             # Bad spot price
@@ -528,7 +534,7 @@ class TestIntraTransaction(unittest.TestCase):
                 RP2Decimal("-1000.0"),
                 RP2Decimal("2.0002"),
                 RP2Decimal("1.9998"),
-                unique_id=19,
+                internal_id=19,
             )
         with self.assertRaisesRegex(RP2TypeError, "Parameter 'spot_price' has non-RP2Decimal value .*"):
             # Bad spot price
@@ -543,7 +549,7 @@ class TestIntraTransaction(unittest.TestCase):
                 "1000",  # type: ignore
                 RP2Decimal("2.0002"),
                 RP2Decimal("1.9998"),
-                unique_id=19,
+                internal_id=19,
             )
         with self.assertRaisesRegex(RP2ValueError, "Parameter 'crypto_sent' has zero value"):
             # Bad crypto sent
@@ -558,7 +564,7 @@ class TestIntraTransaction(unittest.TestCase):
                 RP2Decimal("1000.0"),
                 RP2Decimal("0"),
                 RP2Decimal("1.9998"),
-                unique_id=19,
+                internal_id=19,
             )
         with self.assertRaisesRegex(RP2ValueError, "Parameter 'crypto_sent' has non-positive value .*"):
             # Bad crypto sent
@@ -573,7 +579,7 @@ class TestIntraTransaction(unittest.TestCase):
                 RP2Decimal("1000.0"),
                 RP2Decimal("-2"),
                 RP2Decimal("1.9998"),
-                unique_id=19,
+                internal_id=19,
             )
         with self.assertRaisesRegex(RP2TypeError, "Parameter 'crypto_sent' has non-RP2Decimal value .*"):
             # Bad crypto sent
@@ -588,7 +594,7 @@ class TestIntraTransaction(unittest.TestCase):
                 RP2Decimal("1000.0"),
                 None,  # type: ignore
                 RP2Decimal("1.9998"),
-                unique_id=19,
+                internal_id=19,
             )
         with self.assertRaisesRegex(RP2TypeError, "Parameter 'crypto_sent' has non-RP2Decimal value .*"):
             # Bad crypto sent
@@ -603,7 +609,7 @@ class TestIntraTransaction(unittest.TestCase):
                 RP2Decimal("1000.0"),
                 "-2.0002",  # type: ignore
                 RP2Decimal("1.9998"),
-                unique_id=19,
+                internal_id=19,
             )
         with self.assertRaisesRegex(RP2ValueError, "Parameter 'crypto_received' has non-positive value .*"):
             # Bad crypto received
@@ -618,7 +624,7 @@ class TestIntraTransaction(unittest.TestCase):
                 RP2Decimal("1000.0"),
                 RP2Decimal("2.0002"),
                 RP2Decimal("-2"),
-                unique_id=19,
+                internal_id=19,
             )
         with self.assertRaisesRegex(RP2TypeError, "Parameter 'crypto_received' has non-RP2Decimal value .*"):
             # Bad crypto received
@@ -633,7 +639,7 @@ class TestIntraTransaction(unittest.TestCase):
                 RP2Decimal("1000.0"),
                 RP2Decimal("2.0002"),
                 None,  # type: ignore
-                unique_id=19,
+                internal_id=19,
             )
         with self.assertRaisesRegex(RP2TypeError, "Parameter 'crypto_received' has non-RP2Decimal value .*"):
             # Bad crypto received
@@ -648,10 +654,10 @@ class TestIntraTransaction(unittest.TestCase):
                 RP2Decimal("1000.0"),
                 RP2Decimal("2.0002"),
                 (1, 2, 3),  # type: ignore
-                unique_id=19,
+                internal_id=19,
             )
 
-        with self.assertRaisesRegex(RP2ValueError, "IntraTransaction .*, id.*from/to exchanges/holders are the same: sending to self"):
+        with self.assertLogs(level="WARNING") as log:
             # From/to exchanges/holders are the same: sending to self
             IntraTransaction(
                 self._configuration,
@@ -664,8 +670,10 @@ class TestIntraTransaction(unittest.TestCase):
                 RP2Decimal("1000.0"),
                 RP2Decimal("2.0002"),
                 RP2Decimal("1.9998"),
-                unique_id=19,
+                internal_id=19,
             )
+            self.assertTrue(re.search(".*IntraTransaction.*: from/to exchanges/holders are the same: sending to self", log.output[0]))  # type: ignore
+
         with self.assertRaisesRegex(RP2ValueError, "Parameter 'crypto_sent' has non-positive value .*"):
             # Crypto sent < 0
             IntraTransaction(
@@ -679,7 +687,7 @@ class TestIntraTransaction(unittest.TestCase):
                 RP2Decimal("1000.0"),
                 RP2Decimal("-2.0002"),
                 RP2Decimal("1.9998"),
-                unique_id=19,
+                internal_id=19,
             )
         with self.assertRaisesRegex(RP2ValueError, "Parameter 'crypto_sent' has zero value"):
             # Crypto sent == 0
@@ -694,7 +702,7 @@ class TestIntraTransaction(unittest.TestCase):
                 RP2Decimal("1000.0"),
                 RP2Decimal("0"),
                 RP2Decimal("1.9998"),
-                unique_id=19,
+                internal_id=19,
             )
         with self.assertRaisesRegex(RP2ValueError, "Parameter 'crypto_received' has non-positive value .*"):
             # Crypto received < 0
@@ -709,7 +717,7 @@ class TestIntraTransaction(unittest.TestCase):
                 RP2Decimal("1000.0"),
                 RP2Decimal("2.0002"),
                 RP2Decimal("-1.9998"),
-                unique_id=19,
+                internal_id=19,
             )
         with self.assertRaisesRegex(RP2TypeError, "Parameter 'notes' has non-string value .*"):
             # Bad notes
@@ -724,10 +732,10 @@ class TestIntraTransaction(unittest.TestCase):
                 RP2Decimal("1000.0"),
                 RP2Decimal("2.0002"),
                 RP2Decimal("1.9998"),
-                unique_id=19,
+                internal_id=19,
                 notes=1111,  # type: ignore
             )
-        with self.assertRaisesRegex(RP2ValueError, ".*IntraTransaction .*, id.*: from/to exchanges/holders are the same: sending to self"):
+        with self.assertLogs(level="WARNING") as log:
             # Sender and receiver are the same
             IntraTransaction(
                 self._configuration,
@@ -740,8 +748,9 @@ class TestIntraTransaction(unittest.TestCase):
                 RP2Decimal("1000.0"),
                 RP2Decimal("2.0002"),
                 RP2Decimal("1.9998"),
-                unique_id=19,
+                internal_id=19,
             )
+            self.assertTrue(re.search(".*IntraTransaction.*: from/to exchanges/holders are the same: sending to self", log.output[0]))  # type: ignore
         with self.assertRaisesRegex(RP2ValueError, ".*IntraTransaction .*, id.*crypto sent < crypto received"):
             # Crypto sent < crypto received
             IntraTransaction(
@@ -755,7 +764,7 @@ class TestIntraTransaction(unittest.TestCase):
                 RP2Decimal("1000.0"),
                 RP2Decimal("1.0002"),
                 RP2Decimal("2.9998"),
-                unique_id=19,
+                internal_id=19,
             )
 
 
