@@ -16,6 +16,7 @@ import re
 import unittest
 
 from dateutil.tz import tzoffset
+
 from rp2.configuration import Configuration
 from rp2.entry_types import TransactionType
 from rp2.intra_transaction import IntraTransaction
@@ -46,14 +47,14 @@ class TestOutTransaction(unittest.TestCase):
             RP2Decimal("900.9"),
             RP2Decimal("2.2"),
             RP2Decimal("0.01"),
-            unique_id=38,
+            internal_id=38,
         )
         OutTransaction.type_check("my_instance", out_transaction)
 
         self.assertTrue(out_transaction.is_taxable())
         self.assertEqual(RP2Decimal("1981.98"), out_transaction.fiat_taxable_amount)
         self.assertEqual(RP2Decimal("2.2"), out_transaction.crypto_taxable_amount)
-        self.assertEqual("38", out_transaction.unique_id)
+        self.assertEqual("38", out_transaction.internal_id)
         self.assertEqual(2020, out_transaction.timestamp.year)
         self.assertEqual(6, out_transaction.timestamp.month)
         self.assertEqual(1, out_transaction.timestamp.day)
@@ -82,6 +83,7 @@ class TestOutTransaction(unittest.TestCase):
   spot_price=900.9000
   crypto_out_no_fee=2.20000000
   crypto_fee=0.01000000
+  unique_id=
   is_taxable=True
   fiat_taxable_amount=1981.9800""",
         )
@@ -97,6 +99,7 @@ class TestOutTransaction(unittest.TestCase):
       spot_price=900.9000
       crypto_out_no_fee=2.20000000
       crypto_fee=0.01000000
+      unique_id=
       is_taxable=True
       fiat_taxable_amount=1981.9800
       foobar
@@ -115,6 +118,7 @@ class TestOutTransaction(unittest.TestCase):
                 "spot_price=900.9000, "
                 "crypto_out_no_fee=2.20000000, "
                 "crypto_fee=0.01000000, "
+                "unique_id=, "
                 "is_taxable=True, "
                 "fiat_taxable_amount=1981.9800, "
                 "foobar, "
@@ -133,7 +137,7 @@ class TestOutTransaction(unittest.TestCase):
             RP2Decimal("900.9"),
             RP2Decimal("2.2"),
             RP2Decimal("0.01"),
-            unique_id=38,
+            internal_id=38,
         )
         out_transaction2: OutTransaction = OutTransaction(
             self._configuration,
@@ -145,7 +149,7 @@ class TestOutTransaction(unittest.TestCase):
             RP2Decimal("900.9"),
             RP2Decimal("2.2"),
             RP2Decimal("0.01"),
-            unique_id=38,
+            internal_id=38,
         )
         out_transaction3: OutTransaction = OutTransaction(
             self._configuration,
@@ -157,7 +161,7 @@ class TestOutTransaction(unittest.TestCase):
             RP2Decimal("900.9"),
             RP2Decimal("2.2"),
             RP2Decimal("0.01"),
-            unique_id=7,
+            internal_id=7,
         )
         self.assertEqual(out_transaction, out_transaction)
         self.assertEqual(out_transaction, out_transaction2)
@@ -178,7 +182,7 @@ class TestOutTransaction(unittest.TestCase):
             RP2Decimal("900.9"),
             RP2Decimal("2.2"),
             RP2Decimal("0.01"),
-            unique_id=38,
+            internal_id=38,
         )
         with self.assertRaisesRegex(RP2TypeError, "Parameter 'indent' has non-integer value"):
             out_transaction.to_string(None, repr_format=False, extra_data=["foobar", "qwerty"])  # type: ignore
@@ -208,7 +212,7 @@ class TestOutTransaction(unittest.TestCase):
                     RP2Decimal("10000"),
                     RP2Decimal("1"),
                     RP2Decimal("1"),
-                    unique_id=45,
+                    internal_id=45,
                 ),
             )
         with self.assertRaisesRegex(RP2TypeError, "Parameter 'configuration' is not of type Configuration: .*"):
@@ -223,7 +227,7 @@ class TestOutTransaction(unittest.TestCase):
                 RP2Decimal("900.9"),
                 RP2Decimal("2.2"),
                 RP2Decimal("0"),
-                unique_id=38,
+                internal_id=38,
             )
         with self.assertRaisesRegex(RP2TypeError, "Parameter 'configuration' is not of type Configuration: .*"):
             # Bad configuration
@@ -237,10 +241,10 @@ class TestOutTransaction(unittest.TestCase):
                 RP2Decimal("900.9"),
                 RP2Decimal("2.2"),
                 RP2Decimal("0"),
-                unique_id=38,
+                internal_id=38,
             )
-        with self.assertRaisesRegex(RP2ValueError, "Parameter 'unique_id' has non-positive value .*"):
-            # Bad unique_id
+        with self.assertRaisesRegex(RP2ValueError, "Parameter 'internal_id' has non-positive value .*"):
+            # Bad internal_id
             OutTransaction(
                 self._configuration,
                 "6/1/2020 3:59:59 -04:00",
@@ -251,10 +255,10 @@ class TestOutTransaction(unittest.TestCase):
                 RP2Decimal("900.9"),
                 RP2Decimal("2.2"),
                 RP2Decimal("0"),
-                unique_id=-38,
+                internal_id=-38,
             )
-        with self.assertRaisesRegex(RP2TypeError, "Parameter 'unique_id' has non-integer value .*"):
-            # Bad unique_id
+        with self.assertRaisesRegex(RP2TypeError, "Parameter 'internal_id' has non-integer value .*"):
+            # Bad internal_id
             OutTransaction(
                 self._configuration,
                 "6/1/2020 3:59:59 -04:00",
@@ -265,7 +269,7 @@ class TestOutTransaction(unittest.TestCase):
                 RP2Decimal("900.9"),
                 RP2Decimal("2.2"),
                 RP2Decimal("0"),
-                unique_id=(1, 2, 3),  # type: ignore
+                internal_id=(1, 2, 3),  # type: ignore
             )
         with self.assertRaisesRegex(RP2TypeError, "Parameter 'timestamp' has non-string value .*"):
             # Bad timestamp
@@ -279,7 +283,7 @@ class TestOutTransaction(unittest.TestCase):
                 RP2Decimal("900.9"),
                 RP2Decimal("2.2"),
                 RP2Decimal("0"),
-                unique_id=38,
+                internal_id=38,
             )
         with self.assertRaisesRegex(RP2ValueError, "Parameter 'timestamp' value has no timezone info: .*"):
             # Bad timestamp
@@ -293,7 +297,7 @@ class TestOutTransaction(unittest.TestCase):
                 RP2Decimal("900.9"),
                 RP2Decimal("2.2"),
                 RP2Decimal("0"),
-                unique_id=38,
+                internal_id=38,
             )
         with self.assertRaisesRegex(RP2TypeError, "Parameter 'timestamp' has non-string value .*"):
             # Bad timestamp
@@ -307,7 +311,7 @@ class TestOutTransaction(unittest.TestCase):
                 RP2Decimal("900.9"),
                 RP2Decimal("2.2"),
                 RP2Decimal("0"),
-                unique_id=38,
+                internal_id=38,
             )
         with self.assertRaisesRegex(RP2ValueError, "Parameter 'asset' value is not known: .*"):
             # Bad asset
@@ -321,7 +325,7 @@ class TestOutTransaction(unittest.TestCase):
                 RP2Decimal("900.9"),
                 RP2Decimal("2.2"),
                 RP2Decimal("0"),
-                unique_id=38,
+                internal_id=38,
             )
         with self.assertRaisesRegex(RP2TypeError, "Parameter 'asset' has non-string value .*"):
             # Bad asset
@@ -335,7 +339,7 @@ class TestOutTransaction(unittest.TestCase):
                 RP2Decimal("900.9"),
                 RP2Decimal("2.2"),
                 RP2Decimal("0"),
-                unique_id=38,
+                internal_id=38,
             )
         with self.assertRaisesRegex(RP2ValueError, "Parameter 'exchange' value is not known: .*"):
             # Bad exchange
@@ -349,7 +353,7 @@ class TestOutTransaction(unittest.TestCase):
                 RP2Decimal("900.9"),
                 RP2Decimal("2.2"),
                 RP2Decimal("0"),
-                unique_id=38,
+                internal_id=38,
             )
         with self.assertRaisesRegex(RP2TypeError, "Parameter 'exchange' has non-string value .*"):
             # Bad exchange
@@ -363,7 +367,7 @@ class TestOutTransaction(unittest.TestCase):
                 RP2Decimal("900.9"),
                 RP2Decimal("2.2"),
                 RP2Decimal("0"),
-                unique_id=38,
+                internal_id=38,
             )
         with self.assertRaisesRegex(RP2ValueError, "Parameter 'holder' value is not known: .*"):
             # Bad holder
@@ -377,7 +381,7 @@ class TestOutTransaction(unittest.TestCase):
                 RP2Decimal("900.9"),
                 RP2Decimal("2.2"),
                 RP2Decimal("0"),
-                unique_id=38,
+                internal_id=38,
             )
         with self.assertRaisesRegex(RP2TypeError, "Parameter 'holder' has non-string value .*"):
             # Bad holder
@@ -391,7 +395,7 @@ class TestOutTransaction(unittest.TestCase):
                 RP2Decimal("900.9"),
                 RP2Decimal("2.2"),
                 RP2Decimal("0"),
-                unique_id=38,
+                internal_id=38,
             )
         with self.assertRaisesRegex(RP2ValueError, ".*OutTransaction .*, id.*invalid transaction type .*"):
             # Bad transaction type
@@ -405,7 +409,7 @@ class TestOutTransaction(unittest.TestCase):
                 RP2Decimal("900.9"),
                 RP2Decimal("2.2"),
                 RP2Decimal("0"),
-                unique_id=38,
+                internal_id=38,
             )
         with self.assertRaisesRegex(RP2ValueError, ".*OutTransaction .*, id.*invalid transaction type .*"):
             # Bad transaction type
@@ -419,7 +423,7 @@ class TestOutTransaction(unittest.TestCase):
                 RP2Decimal("900.9"),
                 RP2Decimal("2.2"),
                 RP2Decimal("0"),
-                unique_id=38,
+                internal_id=38,
             )
         with self.assertRaisesRegex(RP2ValueError, "Parameter .* has invalid transaction type value: .*"):
             # Bad transaction type
@@ -433,7 +437,7 @@ class TestOutTransaction(unittest.TestCase):
                 RP2Decimal("900.9"),
                 RP2Decimal("2.2"),
                 RP2Decimal("0"),
-                unique_id=38,
+                internal_id=38,
             )
         with self.assertRaisesRegex(RP2TypeError, "Parameter .* has non-string value .*"):
             # Bad transaction type
@@ -447,7 +451,7 @@ class TestOutTransaction(unittest.TestCase):
                 RP2Decimal("900.9"),
                 RP2Decimal("2.2"),
                 RP2Decimal("0"),
-                unique_id=38,
+                internal_id=38,
             )
         with self.assertRaisesRegex(RP2ValueError, "OutTransaction .*, id.*parameter 'spot_price' cannot be 0"):
             # Bad spot price
@@ -461,7 +465,7 @@ class TestOutTransaction(unittest.TestCase):
                 RP2Decimal("0"),
                 RP2Decimal("2.2"),
                 RP2Decimal("0"),
-                unique_id=38,
+                internal_id=38,
             )
         with self.assertRaisesRegex(RP2ValueError, "Parameter 'spot_price' has non-positive value .*"):
             # Bad spot price
@@ -475,7 +479,7 @@ class TestOutTransaction(unittest.TestCase):
                 RP2Decimal("-900.9"),
                 RP2Decimal("2.2"),
                 RP2Decimal("0"),
-                unique_id=38,
+                internal_id=38,
             )
         with self.assertRaisesRegex(RP2TypeError, "Parameter 'spot_price' has non-RP2Decimal value ,*"):
             # Bad spot price
@@ -489,7 +493,7 @@ class TestOutTransaction(unittest.TestCase):
                 None,  # type: ignore
                 RP2Decimal("2.2"),
                 RP2Decimal("0"),
-                unique_id=38,
+                internal_id=38,
             )
         with self.assertRaisesRegex(RP2ValueError, "Parameter 'crypto_out_no_fee' has zero value"):
             # Bad crypto out no fee
@@ -503,7 +507,7 @@ class TestOutTransaction(unittest.TestCase):
                 RP2Decimal("900.9"),
                 RP2Decimal("0"),
                 RP2Decimal("0"),
-                unique_id=38,
+                internal_id=38,
             )
         with self.assertRaisesRegex(RP2ValueError, "Parameter 'crypto_out_no_fee' has non-positive value .*"):
             # Bad crypto out no fee
@@ -517,7 +521,7 @@ class TestOutTransaction(unittest.TestCase):
                 RP2Decimal("900.9"),
                 RP2Decimal("-2.2"),
                 RP2Decimal("0"),
-                unique_id=38,
+                internal_id=38,
             )
         with self.assertRaisesRegex(RP2TypeError, "Parameter 'crypto_out_no_fee' has non-RP2Decimal value .*"):
             # Bad crypto out no fee
@@ -531,7 +535,7 @@ class TestOutTransaction(unittest.TestCase):
                 RP2Decimal("900.9"),
                 None,  # type: ignore
                 RP2Decimal("0"),
-                unique_id=38,
+                internal_id=38,
             )
         with self.assertRaisesRegex(RP2ValueError, "Parameter 'crypto_fee' has non-positive value .*"):
             # Bad crypto fee
@@ -545,7 +549,7 @@ class TestOutTransaction(unittest.TestCase):
                 RP2Decimal("900.9"),
                 RP2Decimal("2.2"),
                 RP2Decimal("-0.1"),
-                unique_id=38,
+                internal_id=38,
             )
         with self.assertRaisesRegex(RP2TypeError, "Parameter 'crypto_fee' has non-RP2Decimal value .*"):
             # Bad crypto fee
@@ -559,7 +563,7 @@ class TestOutTransaction(unittest.TestCase):
                 RP2Decimal("900.9"),
                 RP2Decimal("2.2"),
                 "foobar",  # type: ignore
-                unique_id=38,
+                internal_id=38,
             )
         with self.assertRaisesRegex(RP2ValueError, "Parameter 'fiat_out_no_fee' has non-positive value .*"):
             # Bad fiat_out_no_fee
@@ -574,7 +578,7 @@ class TestOutTransaction(unittest.TestCase):
                 RP2Decimal("2.2"),
                 RP2Decimal("0"),
                 fiat_out_no_fee=RP2Decimal("-0.1"),
-                unique_id=38,
+                internal_id=38,
             )
         with self.assertRaisesRegex(RP2TypeError, "Parameter 'fiat_out_no_fee' has non-RP2Decimal value .*"):
             # Bad fiat_out_no_fee
@@ -589,7 +593,7 @@ class TestOutTransaction(unittest.TestCase):
                 RP2Decimal("2.2"),
                 RP2Decimal("0"),
                 fiat_out_no_fee="foobar",  # type: ignore
-                unique_id=38,
+                internal_id=38,
             )
 
         with self.assertRaisesRegex(RP2ValueError, "Parameter 'fiat_fee' has non-positive value .*"):
@@ -606,7 +610,7 @@ class TestOutTransaction(unittest.TestCase):
                 RP2Decimal("0"),
                 fiat_out_no_fee=RP2Decimal("1800"),
                 fiat_fee=RP2Decimal("-10"),
-                unique_id=38,
+                internal_id=38,
             )
         with self.assertRaisesRegex(RP2TypeError, "Parameter 'fiat_fee' has non-RP2Decimal value .*"):
             # Bad fiat fee
@@ -622,7 +626,7 @@ class TestOutTransaction(unittest.TestCase):
                 RP2Decimal("0"),
                 fiat_out_no_fee=RP2Decimal("1800"),
                 fiat_fee="foobar",  # type: ignore
-                unique_id=38,
+                internal_id=38,
             )
         with self.assertRaisesRegex(RP2TypeError, "Parameter 'notes' has non-string value .*"):
             # Bad notes
@@ -637,7 +641,7 @@ class TestOutTransaction(unittest.TestCase):
                 RP2Decimal("2.2"),
                 RP2Decimal("0"),
                 notes=(1, 2, 3),  # type: ignore
-                unique_id=38,
+                internal_id=38,
             )
 
         with self.assertLogs(level="WARNING") as log:
@@ -652,7 +656,7 @@ class TestOutTransaction(unittest.TestCase):
                 RP2Decimal("2.2"),
                 RP2Decimal("0.1"),
                 crypto_out_with_fee=RP2Decimal("2.2"),
-                unique_id=38,
+                internal_id=38,
             )
             self.assertTrue(re.search("crypto_out_with_fee != crypto_out_no_fee.*crypto_fee:.*", log.output[0]))  # type: ignore
         with self.assertLogs(level="WARNING") as log:
@@ -668,7 +672,7 @@ class TestOutTransaction(unittest.TestCase):
                 RP2Decimal("0.1"),
                 fiat_out_no_fee=RP2Decimal("1981.98"),
                 fiat_fee=RP2Decimal("5.9"),
-                unique_id=38,
+                internal_id=38,
             )
             self.assertTrue(re.search("crypto_fee.*spot_price.*!= fiat_fee.*:.*", log.output[0]))  # type: ignore
         with self.assertLogs(level="WARNING") as log:
@@ -684,7 +688,7 @@ class TestOutTransaction(unittest.TestCase):
                 RP2Decimal("0.1"),
                 fiat_out_no_fee=RP2Decimal("1081.98"),
                 fiat_fee=RP2Decimal("90.09"),
-                unique_id=38,
+                internal_id=38,
             )
             self.assertTrue(re.search("crypto_out_no_fee.*spot_price.*!= fiat_out_no_fee.*:.*", log.output[0]))  # type: ignore
 
